## Use
The package contains methods for calculating Gaussian distributions.

## How to install
Run **pip install sj_distributions** from your terminal.

## Note
This is for practicing uploading a package to PyPi.